pub struct DiskManagerHandle { /* private fields */ }Expand description
Session-level handle for managing the disk subsystem.
Implementations
Sourceimpl DiskManagerHandle
impl DiskManagerHandle
Sourcepub fn new(config: DiskConfig) -> (Self, JoinHandle<()>)
pub fn new(config: DiskConfig) -> (Self, JoinHandle<()>)
Create a new disk manager with the default backend selected from config.
Returns the handle and a JoinHandle for the background actor task.
Sourcepub async fn register_torrent(
&self,
info_hash: Id20,
storage: Arc<dyn TorrentStorage>,
) -> DiskHandle
pub async fn register_torrent( &self, info_hash: Id20, storage: Arc<dyn TorrentStorage>, ) -> DiskHandle
Register a torrent’s storage with the disk subsystem and return a
per-torrent DiskHandle.
Sourcepub async fn unregister_torrent(&self, info_hash: Id20)
pub async fn unregister_torrent(&self, info_hash: Id20)
Unregister a torrent, flushing and clearing its write buffer and cache.