pub enum MetricKind {
Counter,
Gauge,
}Expand description
Whether a metric is a monotonically increasing counter or a point-in-time gauge.
Variants
Counter
Monotonically increasing (bytes sent, pieces downloaded, etc.).
Gauge
Current value that can go up or down (connections, DHT nodes, etc.).