pub struct TorrentFlags(/* private fields */);Expand description
Bitflag convenience wrapper for common torrent state flags.
These map to existing torrent actor fields; set_flags / unset_flags
delegate to the underlying operations (pause/resume, set_sequential, etc.).
Implementations
Sourceimpl TorrentFlags
impl TorrentFlags
Sourcepub const PAUSED: TorrentFlags
pub const PAUSED: TorrentFlags
Torrent is paused.
Sourcepub const AUTO_MANAGED: TorrentFlags
pub const AUTO_MANAGED: TorrentFlags
Torrent is auto-managed by the session queuing system.
Sourcepub const SEQUENTIAL_DOWNLOAD: TorrentFlags
pub const SEQUENTIAL_DOWNLOAD: TorrentFlags
Sequential (in-order) piece downloading is enabled.
Sourcepub const SUPER_SEEDING: TorrentFlags
pub const SUPER_SEEDING: TorrentFlags
BEP 16 super seeding mode is active.
Sourcepub const UPLOAD_ONLY: TorrentFlags
pub const UPLOAD_ONLY: TorrentFlags
Upload-only status (seeding complete, no wanted pieces).
Sourceimpl TorrentFlags
impl TorrentFlags
Sourcepub const fn empty() -> TorrentFlags
pub const fn empty() -> TorrentFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> TorrentFlags
pub const fn all() -> TorrentFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<TorrentFlags>
pub const fn from_bits(bits: u32) -> Option<TorrentFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> TorrentFlags
pub const fn from_bits_truncate(bits: u32) -> TorrentFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> TorrentFlags
pub const fn from_bits_retain(bits: u32) -> TorrentFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TorrentFlags>
pub fn from_name(name: &str) -> Option<TorrentFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TorrentFlags) -> bool
pub const fn intersects(&self, other: TorrentFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: TorrentFlags) -> bool
pub const fn contains(&self, other: TorrentFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: TorrentFlags)
pub fn insert(&mut self, other: TorrentFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: TorrentFlags)
pub fn remove(&mut self, other: TorrentFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TorrentFlags)
pub fn toggle(&mut self, other: TorrentFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: TorrentFlags, value: bool)
pub fn set(&mut self, other: TorrentFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TorrentFlags) -> TorrentFlags
pub const fn intersection(self, other: TorrentFlags) -> TorrentFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: TorrentFlags) -> TorrentFlags
pub const fn union(self, other: TorrentFlags) -> TorrentFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: TorrentFlags) -> TorrentFlags
pub const fn difference(self, other: TorrentFlags) -> TorrentFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: TorrentFlags) -> TorrentFlags
pub const fn symmetric_difference(self, other: TorrentFlags) -> TorrentFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> TorrentFlags
pub const fn complement(self) -> TorrentFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl TorrentFlags
impl TorrentFlags
Sourcepub const fn iter(&self) -> Iter<TorrentFlags>
pub const fn iter(&self) -> Iter<TorrentFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TorrentFlags>
pub const fn iter_names(&self) -> IterNames<TorrentFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.