ReconfigGuard

Struct ReconfigGuard 

pub struct ReconfigGuard<'g> { /* private fields */ }
RAII guard returned by ReconfigInFlight::try_lock. Releases the slot when dropped.

The 'g lifetime keeps the guard tied to the ReconfigInFlight so the borrow checker prevents the guard from outliving the controller (which would leak the slot permanently).