DiskStats

Struct DiskStats 

pub struct DiskStats {
    pub read_bytes: u64,
    pub write_bytes: u64,
    pub cache_hits: u64,
    pub cache_misses: u64,
    pub write_buffer_bytes: usize,
    pub queued_jobs: usize,
    pub read_cache_bytes: usize,
    pub pool_entries: usize,
    pub prefetch_count: u64,
    pub eviction_count: u64,
    pub skeleton_count: u64,
}
Disk I/O performance counters.

Fields

read_bytes: u64

Total bytes read from disk.

write_bytes: u64

Total bytes written to disk.

cache_hits: u64

Number of read requests served from cache.

cache_misses: u64

Number of read requests that required disk I/O.

write_buffer_bytes: usize

Current size of the write buffer in bytes.

queued_jobs: usize

Number of pending disk I/O jobs in the queue.

read_cache_bytes: usize

Current size of the read cache in bytes (M102).

pool_entries: usize

Total number of entries in the buffer pool (M102).

prefetch_count: u64

Number of prefetch insertions into the read cache (M102).

eviction_count: u64

Number of ARC evictions from the read cache (M102).

skeleton_count: u64

Number of Writing-to-Skeleton demotions (M102).